@@ -31,6 +31,7 @@
 #include <glib/gstdio.h>
 
 #include "capplet-util.h"
+#include "appearance-font.h"
 
 /* X servers sometimes lie about the screen's physical dimensions, so we cannot
  * compute an accurate DPI value.  When this happens, the user gets fonts that
@@ -392,15 +393,16 @@ enum_group_create (GSettings           *settings,
 }
 
 static void
-enum_group_destroy (EnumGroup *group)
+enum_group_destroy (gpointer data)
 {
+  EnumGroup *group = data;
+
   g_signal_handler_disconnect (group->settings, group->settings_signal_id);
   g_clear_object (&group->settings);
   group->settings_signal_id = 0;
   g_free (group->settings_key);
 
-  g_slist_foreach (group->items, (GFunc) g_free, NULL);
-  g_slist_free (group->items);
+  g_slist_free_full (group->items, g_free);
 
   g_free (group);
 }
@@ -610,7 +612,7 @@ cb_add_new_font (GtkWidget *button,
     gint res;
 
     dialog = gtk_file_chooser_dialog_new (_("Select Font"),
-            GTK_WINDOW (appearance_capplet_get_widget (data, "appearance_window")),
+            GET_WINDOW ("appearance_window"),
             action,
             _("_Cancel"),
             GTK_RESPONSE_CANCEL,
@@ -648,7 +650,7 @@ cb_show_details (GtkWidget *button,
     data->font_details = appearance_capplet_get_widget (data, "render_details");
 
     gtk_window_set_transient_for (GTK_WINDOW (data->font_details),
-                                  GTK_WINDOW (appearance_capplet_get_widget (data, "appearance_window")));
+                                  GET_WINDOW ("appearance_window"));
 
     spinner = appearance_capplet_get_widget (data, "dpi_spinner");
     toggle = appearance_capplet_get_widget (data, "dpi_reset_switch");
@@ -795,10 +797,8 @@ void font_init(AppearanceData* data)
 	g_signal_connect (appearance_capplet_get_widget (data, "details_button"), "clicked", G_CALLBACK (cb_show_details), data);
 }
 
-void font_shutdown(AppearanceData* data)
+void font_shutdown (AppearanceData *data)
 {
-	g_slist_foreach(data->font_groups, (GFunc) enum_group_destroy, NULL);
-	g_slist_free(data->font_groups);
-	g_slist_foreach(font_pairs, (GFunc) g_free, NULL);
-	g_slist_free(font_pairs);
+	g_slist_free_full (data->font_groups, enum_group_destroy);
+	g_slist_free_full (font_pairs, g_free);
 }
