@@ -17,6 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
+
 #include "appearance.h"
 
 #include <string.h>
@@ -28,6 +29,7 @@
 #include "gtkrc-utils.h"
 #include "theme-thumbnail.h"
 #include "capplet-util.h"
+#include "appearance-style.h"
 
 #define GSETTINGS_SETTINGS "GSETTINGS_SETTINGS"
 #define GSETTINGS_KEY      "GSETTINGS_KEY"
@@ -322,8 +324,7 @@ check_color_schemes_enabled (GtkSettings *settings,
     enable_colors |= found;
   }
 
-  g_slist_foreach (symbolic_colors, (GFunc) g_free, NULL);
-  g_slist_free (symbolic_colors);
+  g_slist_free_full (symbolic_colors, g_free);
 
   gtk_widget_set_sensitive (appearance_capplet_get_widget (data, "color_scheme_table"), enable_colors);
   gtk_widget_set_sensitive (appearance_capplet_get_widget (data, "color_scheme_defaults_button"), enable_colors);
@@ -1019,11 +1020,6 @@ style_init (AppearanceData *data)
   w = appearance_capplet_get_widget (data, "color_scheme_message_hbox");
   gtk_widget_set_no_show_all (w, TRUE);
 
-  w = appearance_capplet_get_widget (data, "color_scheme_defaults_button");
-  gtk_button_set_image (GTK_BUTTON (w),
-                        gtk_image_new_from_icon_name ("document-revert",
-                                                      GTK_ICON_SIZE_BUTTON));
-
   settings = gtk_settings_get_default ();
   g_signal_connect (settings, "notify::gtk-color-scheme", (GCallback) color_scheme_changed, data);
 
