@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2012 Stefano Karapetsas
+ * Copyright (C) 2012-2021 MATE Developers
  * Authors: Stefano Karapetsas <stefano@karapetsas.com>
  * All Rights Reserved
  *
@@ -18,5 +19,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifndef __APPEARANCE_SUPPORT_H__
+#define __APPEARANCE_SUPPORT_H__
+
 void support_init(AppearanceData* data);
 void support_shutdown(AppearanceData* data);
+
+#endif /* __APPEARANCE_SUPPORT_H__ */
