@@ -19,6 +19,7 @@
  */
 
 #include "appearance.h"
+#include "mate-wp-xml.h"
 #include "mate-wp-item.h"
 #include <gio/gio.h>
 #include <string.h>
@@ -124,10 +125,12 @@ static void mate_wp_xml_load_xml(AppearanceData* data, const char* filename)
 	xmlNode* list;
 	xmlNode* wpa;
 	xmlChar* nodelang;
+#ifdef ENABLE_NLS
 	const char* const* syslangs;
+	gint i;
+#endif /* ENABLE_NLS */
 	GdkRGBA color1;
 	GdkRGBA color2;
-	gint i;
 
 	wplist = xmlParseFile(filename);
 
@@ -136,7 +139,9 @@ static void mate_wp_xml_load_xml(AppearanceData* data, const char* filename)
 		return;
 	}
 
+#ifdef ENABLE_NLS
 	syslangs = g_get_language_names();
+#endif /* ENABLE_NLS */
 
 	root = xmlDocGetRootElement(wplist);
 
@@ -154,11 +159,12 @@ static void mate_wp_xml_load_xml(AppearanceData* data, const char* filename)
 
 			for (wpa = list->children; wpa != NULL; wpa = wpa->next)
 			{
-				if (wpa->type == XML_COMMENT_NODE)
+				if (wpa->type != XML_ELEMENT_NODE)
 				{
 					continue;
 				}
-				else if (!strcmp ((char*) wpa->name, "filename"))
+
+				if (!strcmp ((char*) wpa->name, "filename"))
 				{
 					if (wpa->last != NULL && wpa->last->content != NULL)
 					{
@@ -193,6 +199,7 @@ static void mate_wp_xml_load_xml(AppearanceData* data, const char* filename)
 						{
 							wp->name = g_strdup (g_strstrip ((char *)wpa->last->content));
 						}
+#ifdef ENABLE_NLS
 						else
 						{
 							for (i = 0; syslangs[i] != NULL; i++)
@@ -205,6 +212,7 @@ static void mate_wp_xml_load_xml(AppearanceData* data, const char* filename)
 								}
 							}
 						}
+#endif /* ENABLE_NLS */
 
 						xmlFree (nodelang);
 					}
@@ -469,7 +477,6 @@ void mate_wp_xml_save_list(AppearanceData* data)
 	xmlDoc* wplist;
 	xmlNode* root;
 	xmlNode* wallpaper;
-	//xmlNode* item;
 	GSList* list = NULL;
 
 	g_hash_table_foreach(data->wp_hash, (GHFunc) mate_wp_list_flatten, &list);
