@@ -30,6 +30,8 @@
 #include <fcntl.h>
 #include <gtk/gtk.h>
 
+#include "gtkrc-utils.h"
+
 #define INCLUDE_SYMBOL ((gpointer) 1)
 #define ENGINE_SYMBOL ((gpointer) 2)
 #define COLOR_SCHEME_SYMBOL ((gpointer) 3)
@@ -46,11 +48,11 @@ gchar* gtkrc_find_named(const gchar* name)
 	/* First look in the users home directory
 	*/
 	home_dir = g_get_home_dir();
-	
+
 	if (home_dir)
 	{
 		path = g_build_filename(home_dir, ".themes", name, subpath, NULL);
-		
+
 		if (!g_file_test (path, G_FILE_TEST_EXISTS))
 		{
 			g_free (path);
@@ -60,15 +62,19 @@ gchar* gtkrc_find_named(const gchar* name)
 
 	if (!path)
 	{
-		gchar* theme_dir = gtk_rc_get_theme_dir();
-		path = g_build_filename(theme_dir, name, subpath, NULL);
-		g_free(theme_dir);
+		const gchar * const * dirs = g_get_system_data_dirs();
 
-		if (!g_file_test(path, G_FILE_TEST_EXISTS))
-		{
-			g_free (path);
-			path = NULL;
-		}
+		if (dirs != NULL)
+			for (; !path && *dirs != NULL; ++dirs)
+			{
+				path = g_build_filename(*dirs, "themes", name, subpath, NULL);
+
+				if (!g_file_test(path, G_FILE_TEST_EXISTS))
+				{
+					g_free (path);
+					path = NULL;
+				}
+			}
 	}
 
 	return path;
@@ -91,7 +97,7 @@ void gtkrc_get_details(gchar* filename, GSList** engines, GSList** symbolic_colo
 	}
 
 	files = g_slist_prepend (files, g_strdup (filename));
-	
+
 	while (files != NULL)
 	{
 		filename = files->data;
@@ -165,8 +171,7 @@ void gtkrc_get_details(gchar* filename, GSList** engines, GSList** symbolic_colo
 		}
 	}
 
-	g_slist_foreach (read_files, (GFunc) g_free, NULL);
-	g_slist_free (read_files);
+	g_slist_free_full (read_files, g_free);
 
 	g_scanner_destroy (scanner);
 }
@@ -231,8 +236,7 @@ gtkrc_get_color_scheme (const gchar *gtkrc_file)
 		}
 	}
 
-	g_slist_foreach (read_files, (GFunc) g_free, NULL);
-	g_slist_free (read_files);
+	g_slist_free_full (read_files, g_free);
 
 	g_scanner_destroy (scanner);
 	return result;
