@@ -29,7 +29,8 @@
 
 #define VISUAL_SCHEMA         "org.mate.applications-at-visual"
 #define VISUAL_KEY            "exec"
-#define VISUAL_STARTUP_KEY    "startup"
+#define VISUAL_STARTUP_SCHEMA "org.gnome.desktop.a11y.applications"
+#define VISUAL_STARTUP_KEY    "screen-reader-enabled"
 
 #define MOBILITY_SCHEMA       "org.mate.applications-at-mobility"
 #define MOBILITY_KEY          "exec"
@@ -38,6 +39,9 @@
 #define CALCULATOR_SCHEMA     "org.mate.applications-calculator"
 #define CALCULATOR_KEY        "exec"
 
+#define MESSENGER_SCHEMA     "org.mate.applications-messenger"
+#define MESSENGER_KEY        "exec"
+
 typedef struct _MateDACapplet {
 	GtkBuilder* builder;
 
@@ -59,6 +63,7 @@ typedef struct _MateDACapplet {
 	GtkWidget* word_combo_box;
 	GtkWidget* spreadsheet_combo_box;
 	GtkWidget* calculator_combo_box;
+        GtkWidget* messenger_combo_box;
 
 	/* Visual Accessibility */
 	GtkWidget* visual_startup_checkbutton;
@@ -81,12 +86,15 @@ typedef struct _MateDACapplet {
 	GList* word_editors;
 	GList* spreadsheet_editors;
 	GList* calculators;
+        GList* messengers;
 
 	/* Settings objects */
 	GSettings* terminal_settings;
 	GSettings* visual_settings;
+	GSettings* visual_startup_settings;
 	GSettings* mobility_settings;
 	GSettings* calculator_settings;
+	GSettings* messenger_settings;
 } MateDACapplet;
 
 #endif
