@@ -50,49 +50,6 @@ static GSettings * keyboard_settings = NULL;
 static GSettings * interface_settings = NULL;
 static GSettings * typing_break_settings = NULL;
 
-static GtkBuilder *
-create_dialog (void)
-{
-	GtkBuilder *dialog;
-	GtkSizeGroup *size_group;
-	GtkWidget *image;
-	GError *error = NULL;
-
-	dialog = gtk_builder_new ();
-	if (gtk_builder_add_from_resource (dialog, "/org/mate/mcc/keyboard/mate-keyboard-properties-dialog.ui", &error) == 0) {
-		g_warning ("Could not load UI: %s", error->message);
-		g_error_free (error);
-		g_object_unref (dialog);
-		return NULL;
-	}
-
-	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (size_group, WID ("repeat_slow_label"));
-	gtk_size_group_add_widget (size_group, WID ("delay_short_label"));
-	gtk_size_group_add_widget (size_group, WID ("blink_slow_label"));
-	g_object_unref (G_OBJECT (size_group));
-
-	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (size_group, WID ("repeat_fast_label"));
-	gtk_size_group_add_widget (size_group, WID ("delay_long_label"));
-	gtk_size_group_add_widget (size_group, WID ("blink_fast_label"));
-	g_object_unref (G_OBJECT (size_group));
-
-	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (size_group, WID ("repeat_delay_scale"));
-	gtk_size_group_add_widget (size_group, WID ("repeat_speed_scale"));
-	gtk_size_group_add_widget (size_group, WID ("cursor_blink_time_scale"));
-	g_object_unref (G_OBJECT (size_group));
-
-	image = gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (WID ("xkb_layouts_add")), image);
-
-	image = gtk_image_new_from_icon_name ("view-refresh", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (WID ("xkb_reset_to_defaults")), image);
-
-	return dialog;
-}
-
 static void
 dialog_response (GtkWidget * widget,
 		 gint response_id, guint data)
@@ -237,17 +194,16 @@ main (int argc, char **argv)
 	interface_settings = g_settings_new (INTERFACE_SCHEMA);
 	typing_break_settings = g_settings_new (TYPING_BREAK_SCHEMA);
 
-	dialog = create_dialog ();
-	if (!dialog) /* Warning was already printed to console */
-		exit (EXIT_FAILURE);
+	dialog = gtk_builder_new_from_resource ("/org/mate/mcc/keyboard/mate-keyboard-properties-dialog.ui");
 
 	setup_dialog (dialog);
 
         GtkNotebook* nb = GTK_NOTEBOOK (WID ("keyboard_notebook"));
         gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
-        g_signal_connect (GTK_WIDGET (nb), "scroll-event",
-                          G_CALLBACK (capplet_dialog_page_scroll_event_cb),
-                          GTK_WINDOW (WID ("keyboard_dialog")));
+        g_signal_connect (GTK_WIDGET (nb),
+                          "scroll-event",
+                          G_CALLBACK (capplet_notebook_scroll_event_cb),
+                          NULL);
 
 	if (switch_to_typing_break_page) {
 		gtk_notebook_set_current_page (nb, 4);
