@@ -1,7 +1,8 @@
 /* mate-network-properties.c: network preferences capplet
  *
  * Copyright (C) 2002 Sun Microsystems Inc.
- *               2012 Stefano Karapetsas
+ * Copyright (C) 2012 Stefano Karapetsas
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Written by: Mark McLoughlin <mark@skynet.ie>
  *             Stefano Karapetsas <stefano@karapetsas.com>
@@ -231,8 +232,7 @@ cb_dialog_response (GtkDialog *dialog, gint response_id)
 	else if (response_id == GTK_RESPONSE_CLOSE || response_id == GTK_RESPONSE_DELETE_EVENT)
 	{
 		if (ignore_hosts) {
-			g_slist_foreach (ignore_hosts, (GFunc) g_free, NULL);
-			g_slist_free (ignore_hosts);
+			g_slist_free_full (ignore_hosts, g_free);
 		}
 
 		gtk_main_quit ();
@@ -368,8 +368,7 @@ connect_sensitivity_signals (GtkBuilder *builder, GSList *mode_group)
 static void
 cb_ignore_hosts_gsettings_changed (GSettings *settings, gchar *key, gpointer user_data)
 {
-	g_slist_foreach (ignore_hosts, (GFunc) g_free, NULL);
-	g_slist_free (ignore_hosts);
+	g_slist_free_full (ignore_hosts, g_free);
 
 	read_ignore_hosts_from_gsettings ();
 
@@ -482,9 +481,10 @@ main (int argc, char **argv)
 
         GtkNotebook* nb = GTK_NOTEBOOK (_gtk_builder_get_widget (builder, "notebook1"));
         gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
-        g_signal_connect (GTK_WIDGET (nb), "scroll-event",
-                          G_CALLBACK (capplet_dialog_page_scroll_event_cb),
-                          GTK_WINDOW (widget));
+        g_signal_connect (GTK_WIDGET (nb),
+                          "scroll-event",
+                          G_CALLBACK (capplet_notebook_scroll_event_cb),
+                          NULL);
 
 	capplet_set_icon (widget, "network-server");
 	gtk_widget_show_all (widget);
