@@ -62,7 +62,7 @@ struct _SushiFontWidgetPrivate {
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 static guint signals[NUM_SIGNALS] = { 0, };
 
-G_DEFINE_TYPE (SushiFontWidget, sushi_font_widget, GTK_TYPE_DRAWING_AREA);
+G_DEFINE_TYPE_WITH_PRIVATE (SushiFontWidget, sushi_font_widget, GTK_TYPE_DRAWING_AREA);
 
 #define SURFACE_SIZE 4
 #define SECTION_SPACING 16
@@ -154,7 +154,7 @@ build_charlist_for_face (FT_Face face,
   GString *string;
   gulong c;
   guint glyph;
-  gint total_chars = 0; 
+  gint total_chars = 0;
 
   string = g_string_new (NULL);
 
@@ -254,7 +254,7 @@ build_strings_for_face (SushiFontWidget *self)
   self->priv->font_name = NULL;
 
   if (self->priv->face->family_name != NULL) {
-    gchar *font_name = 
+    gchar *font_name =
       g_strconcat (self->priv->face->family_name, " ",
                    self->priv->face->style_name, NULL);
 
@@ -387,7 +387,7 @@ sushi_font_widget_size_request (GtkWidget *drawing_area,
 
   if (self->priv->lowercase_text != NULL) {
     cairo_text_extents (cr, self->priv->lowercase_text, &extents);
-    pixmap_height += font_extents.ascent + font_extents.descent + 
+    pixmap_height += font_extents.ascent + font_extents.descent +
       extents.y_advance + LINE_SPACING;
     pixmap_width = MAX (pixmap_width, extents.width + padding.left + padding.right);
   }
@@ -586,8 +586,7 @@ sushi_font_widget_init (SushiFontWidget *self)
 {
   FT_Error err;
 
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, SUSHI_TYPE_FONT_WIDGET,
-                                            SushiFontWidgetPrivate);
+  self->priv = sushi_font_widget_get_instance_private (self);
 
   self->priv->face = NULL;
   err = FT_Init_FreeType (&self->priv->library);
@@ -716,7 +715,6 @@ sushi_font_widget_class_init (SushiFontWidgetClass *klass)
                   G_TYPE_NONE, 1, G_TYPE_STRING);
 
   g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
-  g_type_class_add_private (klass, sizeof (SushiFontWidgetPrivate));
 }
 
 SushiFontWidget *
