@@ -45,7 +45,6 @@
 #include "themed-icon.h"
 
 #define TILE_EXEC_NAME "Tile_desktop_exec_name"
-#define SECONDS_IN_DAY 86400
 #define CC_SCHEMA "org.mate.control-center"
 #define EXIT_SHELL_ON_ACTION_START "cc-exit-shell-on-action-start"
 #define EXIT_SHELL_ON_ACTION_HELP "cc-exit-shell-on-action-help"
@@ -465,7 +464,7 @@ populate_groups_section (AppShellData * app_data)
 		CategoryData *data = (CategoryData *) cat_list->data;
 		if (NULL != data->filtered_launcher_list)
 		{
-			gtk_widget_set_state (GTK_WIDGET (data->group_launcher), GTK_STATE_NORMAL);
+			gtk_widget_set_state_flags (GTK_WIDGET (data->group_launcher), GTK_STATE_FLAG_NORMAL, FALSE);
 			gtk_box_pack_start (vbox, GTK_WIDGET (data->group_launcher),
 				FALSE, FALSE, 0);
 		}
@@ -624,7 +623,7 @@ generate_filtered_lists (gpointer catdata, gpointer user_data)
 
 		/* Since the filter may remove this entry from the
 		   container it will not get a mouse out event */
-		gtk_widget_set_state (GTK_WIDGET (launcher), GTK_STATE_NORMAL);
+		gtk_widget_set_state_flags (GTK_WIDGET (launcher), GTK_STATE_FLAG_NORMAL, FALSE);
 		filename = g_object_get_data (G_OBJECT (launcher), TILE_EXEC_NAME); /* do I need to free this */
 
 		temp1 = g_ascii_strdown (launcher->name, -1);
@@ -724,9 +723,9 @@ create_application_category_sections (AppShellData * app_data)
 		g_free (markup);
 
 		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		table = gtk_table_new (0, 0, TRUE);
-		gtk_table_set_col_spacings (GTK_TABLE (table), 5);
-		gtk_table_set_row_spacings (GTK_TABLE (table), 5);
+		table = gtk_grid_new ();
+		gtk_grid_set_column_spacing (GTK_GRID (table), 5);
+		gtk_grid_set_row_spacing (GTK_GRID (table), 5);
 		gtk_box_pack_start (GTK_BOX (hbox), table, FALSE, FALSE, 15);
 		slab_section_set_contents (SLAB_SECTION (data->section), hbox);
 	}
@@ -805,7 +804,7 @@ populate_application_category_section (AppShellData * app_data, SlabSection * se
 	GList * launcher_list)
 {
 	GtkWidget *hbox;
-	GtkTable *table;
+	GtkGrid *table;
 	GList *children;
 
 	hbox = GTK_WIDGET (section->contents);
@@ -814,8 +813,8 @@ populate_application_category_section (AppShellData * app_data, SlabSection * se
 	table = children->data;
 	g_list_free (children);
 
-	/* Make sure our implementation has not changed and it's still a GtkTable */
-	g_assert (GTK_IS_TABLE (table));
+	/* Make sure our implementation has not changed and it's still a GtkGrid */
+	g_assert (GTK_IS_GRID (table));
 
 	app_data->cached_tables_list = g_list_append (app_data->cached_tables_list, table);
 
