@@ -112,8 +112,6 @@ static void store_monitor_cb (GFileMonitor *, GFile *, GFile *,
                               GFileMonitorEvent, gpointer);
 static void weak_destroy_cb  (gpointer, GObject *);
 
-static gint recent_item_mru_comp_func (gconstpointer a, gconstpointer b);
-
 static gchar *find_package_data_file (const gchar *filename);
 
 static gint BookmarkAgent_private_offset;
@@ -148,22 +146,6 @@ bookmark_agent_get_type ()
 	return g_define_type_id;
 }
 
-BookmarkAgent *
-bookmark_agent_get_instance (BookmarkStoreType type)
-{
-	g_return_val_if_fail (0 <= type, NULL);
-	g_return_val_if_fail (type < BOOKMARK_STORE_N_TYPES, NULL);
-
-	if (! instances [type]) {
-		instances [type] = bookmark_agent_new (type);
-		g_object_weak_ref (G_OBJECT (instances [type]), weak_destroy_cb, GINT_TO_POINTER (type));
-	}
-	else
-		g_object_ref (G_OBJECT (instances [type]));
-
-	return instances [type];
-}
-
 gboolean
 bookmark_agent_has_item (BookmarkAgent *this, const gchar *uri)
 {
@@ -186,7 +168,7 @@ bookmark_agent_add_item (BookmarkAgent *this, const BookmarkItem *item)
 	g_bookmark_file_set_mime_type (priv->store, item->uri, item->mime_type);
 
 	if (item->mtime)
-		g_bookmark_file_set_modified (priv->store, item->uri, item->mtime);
+		g_bookmark_file_set_modified_date_time (priv->store, item->uri, item->mtime);
 
 	if (item->title)
 		g_bookmark_file_set_title (priv->store, item->uri, item->title);
@@ -339,13 +321,13 @@ make_items_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *store)
 
 			item->uri       = g_strdup (uris [i]);
 			item->mime_type = g_bookmark_file_get_mime_type (store, uris [i], NULL);
-			item->mtime     = g_bookmark_file_get_modified  (store, uris [i], NULL);
+			item->mtime     = g_bookmark_file_get_modified_date_time  (store, uris [i], NULL);
 
 			items_ordered = g_list_prepend (items_ordered, item);
 		}
 	}
 
-	items_ordered = g_list_sort (items_ordered, recent_item_mru_comp_func);
+	items_ordered = g_list_sort (items_ordered, g_date_time_compare);
 
 	g_strfreev (uris);
 
@@ -374,7 +356,7 @@ bookmark_agent_update_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *st
 		item = (BookmarkItem *) node->data;
 
 		g_bookmark_file_set_mime_type (priv->store, item->uri, item->mime_type);
-		g_bookmark_file_set_modified  (priv->store, item->uri, item->mtime);
+		g_bookmark_file_set_modified_date_time  (priv->store, item->uri, item->mtime);
 
 		bookmark_item_free (item);
 	}
@@ -562,6 +544,22 @@ bookmark_agent_new (BookmarkStoreType type)
 	return this;
 }
 
+BookmarkAgent *
+bookmark_agent_get_instance (BookmarkStoreType type)
+{
+	g_return_val_if_fail (0 <= type, NULL);
+	g_return_val_if_fail (type < BOOKMARK_STORE_N_TYPES, NULL);
+
+	if (! instances [type]) {
+		instances [type] = bookmark_agent_new (type);
+		g_object_weak_ref (G_OBJECT (instances [type]), weak_destroy_cb, GINT_TO_POINTER (type));
+	}
+	else
+		g_object_ref (G_OBJECT (instances [type]));
+
+	return instances [type];
+}
+
 static void
 get_property (GObject *g_obj, guint prop_id, GValue *value, GParamSpec *pspec)
 {
@@ -720,7 +718,7 @@ update_items (BookmarkAgent *this)
 			priv->items [i]->uri       = g_strdup (uris_ordered [i]);
 			priv->items [i]->title     = g_bookmark_file_get_title     (priv->store, uris_ordered [i], NULL);
 			priv->items [i]->mime_type = g_bookmark_file_get_mime_type (priv->store, uris_ordered [i], NULL);
-			priv->items [i]->mtime     = g_bookmark_file_get_modified  (priv->store, uris_ordered [i], NULL);
+			priv->items [i]->mtime     = g_bookmark_file_get_modified_date_time (priv->store, uris_ordered [i], NULL);
 			priv->items [i]->app_name  = NULL;
 			priv->items [i]->app_exec  = NULL;
 
@@ -997,7 +995,7 @@ update_user_spec_path (BookmarkAgent *this)
 		}
 	}
 
-	if (libslab_strcmp (priv->store_path, path)) {
+	if (g_strcmp0 (priv->store_path, path)) {
 		g_free (priv->store_path);
 		priv->store_path = path;
 
@@ -1060,7 +1058,7 @@ create_app_item (BookmarkAgent *this, const gchar *uri)
 	if (! uri_new)
 		return;
 
-	if (libslab_strcmp (uri, uri_new))
+	if (g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	g_free (uri_new);
@@ -1119,7 +1117,7 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 	if (!uri_new)
 		return;
 
-	if (libslab_strcmp (uri, uri_new))
+	if (g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	g_free (uri_new);
@@ -1203,7 +1201,7 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 	if (name)
 		g_bookmark_file_set_title (priv->store, uri, name);
 
-	if (uri_new && libslab_strcmp (uri, uri_new))
+	if (uri_new && g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	if (gotta_free_name) {
@@ -1226,9 +1224,3 @@ weak_destroy_cb (gpointer data, GObject *g_obj)
 {
 	instances [GPOINTER_TO_INT (data)] = NULL;
 }
-
-static gint
-recent_item_mru_comp_func (gconstpointer a, gconstpointer b)
-{
-	return ((BookmarkItem *) b)->mtime - ((BookmarkItem *) a)->mtime;
-}
