@@ -21,11 +21,10 @@
 #ifndef __NLD_SEARCH_BAR_H__
 #define __NLD_SEARCH_BAR_H__
 
+#include <glib.h>
 #include <gtk/gtk.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
 #define NLD_TYPE_SEARCH_BAR            (nld_search_bar_get_type ())
 #define NLD_SEARCH_BAR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NLD_TYPE_SEARCH_BAR, NldSearchBar))
@@ -43,7 +42,7 @@ typedef struct
 {
 	GtkBoxClass parent_class;
 
-	void (*search) (NldSearchBar *, int context_id, const char *text);
+	void (*search) (NldSearchBar *, const char *text);
 } NldSearchBarClass;
 
 GType nld_search_bar_get_type (void);
@@ -53,11 +52,6 @@ GtkWidget *nld_search_bar_new (void);
 void nld_search_bar_clear (NldSearchBar * search_bar);
 gboolean nld_search_bar_has_focus (NldSearchBar * search_bar);
 
-gboolean nld_search_bar_get_show_contexts (NldSearchBar * search_bar);
-void nld_search_bar_set_show_contexts (NldSearchBar * search_bar, gboolean show_contexts);
-void nld_search_bar_add_context (NldSearchBar * search_bar, const char *label,
-	const char *icon_name, int context_id);
-
 gboolean nld_search_bar_get_show_button (NldSearchBar * search_bar);
 void nld_search_bar_set_show_button (NldSearchBar * search_bar, gboolean show_button);
 
@@ -67,10 +61,6 @@ void nld_search_bar_set_search_timeout (NldSearchBar * search_bar, int search_ti
 const char *nld_search_bar_get_text (NldSearchBar * search_bar);
 void nld_search_bar_set_text (NldSearchBar * search_bar, const char *text, gboolean activate);
 
-int nld_search_bar_get_context_id (NldSearchBar * search_bar);
-void nld_search_bar_set_context_id (NldSearchBar * search_bar, int context_id);
+G_END_DECLS
 
-#ifdef __cplusplus
-}
-#endif
 #endif /* __NLD_SEARCH_BAR_H__ */
