@@ -32,23 +32,21 @@
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-
-#include <sys/types.h>
-#include <dirent.h>
 #include <string.h>
 
 typedef struct {
-        MateDesktopItem *ditem;
-        char *name; /* human readable, localized */
-        char *identify_name; /* name we expect to be set on the screen */
-        char *exec;
-        char *config_exec;
-        char *config_tryexec;
-        char *module;
-        guint session_managed : 1;
-        guint is_user : 1;
-        guint is_present : 1;
-        guint is_config_present : 1;
+        MateDesktopItem   *ditem;
+        char              *name; /* human readable, localized */
+        char              *identify_name; /* name we expect to be set on the screen */
+        char              *exec;
+        char              *tryexec;
+        char              *config_exec;
+        char              *config_tryexec;
+        char              *module;
+        gboolean           session_managed;
+        gboolean           is_user;
+        gboolean           is_present;
+        gboolean           is_config_present;
         MateWindowManager *mate_wm;
 } AvailableWindowManager;
 
@@ -60,6 +58,7 @@ wm_free (AvailableWindowManager *wm)
 {
         g_free (wm->name);
         g_free (wm->exec);
+        g_free (wm->tryexec);
         g_free (wm->config_exec);
         g_free (wm->config_tryexec);
         g_free (wm->module);
@@ -69,32 +68,48 @@ wm_free (AvailableWindowManager *wm)
 }
 
 static GList *
-list_desktop_files_in_dir (gchar *directory)
+list_desktop_files_in_dir (const gchar *directory)
 {
-        DIR *dir;
-        struct dirent *child;
-        GList *result = NULL;
-        gchar *suffix;
+        GDir        *dir;
+        GList       *result = NULL;
+        const gchar *suffix;
+        const gchar *name;
+        const char* const ext = ".desktop";
+        size_t       ext_len;
+        GError      *error = NULL;
 
-        dir = opendir (directory);
-        if (dir == NULL)
+        dir = g_dir_open (directory, 0, &error);
+
+        if (error) {
+                g_debug ("Could not read the folder content: %s",
+                         error->message);
+                g_error_free (error);
                 return NULL;
+        }
 
-        while ((child = readdir (dir)) != NULL) {
+        ext_len = strlen (ext);
+
+        while ((name = g_dir_read_name (dir)) != NULL) {
                 /* Ignore files without .desktop suffix, and ignore
                  * .desktop files with no prefix
                  */
-                suffix = child->d_name + strlen (child->d_name) - 8;
-                /* strlen(".desktop") == 8 */
+                size_t name_len;
 
-                if (suffix <= child->d_name ||
-                    strcmp (suffix, ".desktop") != 0)
+                name_len = strlen (name);
+
+                if (name_len <= ext_len)
+                        continue;
+
+                suffix = name + name_len - ext_len;
+
+                if (strcmp (suffix, ext) != 0)
                         continue;
 
                 result = g_list_prepend (result,
-                                         g_build_filename (directory, child->d_name, NULL));
+                                         g_build_filename (directory, name, NULL));
         }
-        closedir (dir);
+
+        g_dir_close (dir);
 
         return result;
 }
@@ -115,13 +130,12 @@ static AvailableWindowManager*
 wm_load (const char *desktop_file,
          gboolean    is_user)
 {
-        gchar *path;
         AvailableWindowManager *wm;
+        gchar                  *path;
 
         wm = g_new0 (AvailableWindowManager, 1);
 
         wm->ditem = mate_desktop_item_new_from_file (desktop_file, 0, NULL);
-
         if (wm->ditem == NULL) {
                 g_free (wm);
                 return NULL;
@@ -129,56 +143,45 @@ wm_load (const char *desktop_file,
 
         mate_desktop_item_set_entry_type (wm->ditem, MATE_DESKTOP_ITEM_TYPE_APPLICATION);
 
-        wm->exec = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                            MATE_DESKTOP_ITEM_EXEC));
+        #define GET_STRING(X) g_strdup (mate_desktop_item_get_string (wm->ditem, (X)))
+        #define GET_BOOLEAN(X) mate_desktop_item_get_boolean (wm->ditem, (X))
 
-        wm->name = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                            MATE_DESKTOP_ITEM_NAME));
+        wm->exec            = GET_STRING (MATE_DESKTOP_ITEM_EXEC);
+        wm->tryexec         = GET_STRING (MATE_DESKTOP_ITEM_TRY_EXEC);
+        wm->name            = GET_STRING (MATE_DESKTOP_ITEM_NAME);
+        wm->config_exec     = GET_STRING ("ConfigExec");
+        wm->config_tryexec  = GET_STRING ("ConfigTryExec");
+        wm->session_managed = GET_BOOLEAN ("SessionManaged");
+        wm->module          = GET_STRING ("X-MATE-WMSettingsModule");
+        wm->identify_name   = GET_STRING ("X-MATE-WMName");
+        wm->is_user         = is_user;
 
-        wm->config_exec = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                                   "ConfigExec"));
-        wm->config_tryexec = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                                      "ConfigTryExec"));
-        wm->session_managed = mate_desktop_item_get_boolean (wm->ditem,
-                                                              "SessionManaged");
+        #undef GET_STRING
+        #undef GET_BOOLEAN
 
-        wm->module = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                              "X-MATE-WMSettingsModule"));
+        if (wm->exec) {
+                const char* exec;
 
-        wm->identify_name = g_strdup (mate_desktop_item_get_string (wm->ditem,
-                                                                     "X-MATE-WMName"));
-
-        wm->is_user = is_user;
-
-        if (mate_desktop_item_get_string (wm->ditem, MATE_DESKTOP_ITEM_EXEC)) {
-                const char *tryexec;
-
-                tryexec = mate_desktop_item_get_string (wm->ditem, MATE_DESKTOP_ITEM_TRY_EXEC);
-
-                if (tryexec) {
-                        path = g_find_program_in_path (tryexec);
-                        wm->is_present = (path != NULL);
-                        if (path)
-                                g_free (path);
-                } else
+                exec  = wm->tryexec ? wm->tryexec : wm->exec;
+                if ((path = g_find_program_in_path (exec)) != NULL) {
                         wm->is_present = TRUE;
-        } else
-                wm->is_present = FALSE;
+                        g_free (path);
+                } else {
+                        wm->is_present = FALSE;
+                }
+        }
 
         if (wm->config_exec) {
-                if (wm->config_tryexec) {
-                        path = g_find_program_in_path (wm->config_tryexec);
-                        wm->is_config_present = (path != NULL);
-                        if (path)
-                                g_free (path);
+                const char* exec;
+
+                exec  = wm->config_tryexec ? wm->config_tryexec : wm->config_exec;
+                if ((path = g_find_program_in_path (exec)) != NULL) {
+                        wm->is_config_present = TRUE;
+                        g_free (path);
                 } else {
-			path = g_find_program_in_path (wm->config_exec);
-                        wm->is_config_present = (path != NULL);
-                        if (path)
-                                g_free (path);
-		}
-        } else
-                wm->is_config_present = FALSE;
+                        wm->is_config_present = FALSE;
+                }
+        }
 
         if (wm->name && wm->exec &&
             (wm->is_user || wm->is_present))
@@ -190,7 +193,7 @@ wm_load (const char *desktop_file,
 }
 
 static void
-scan_wm_directory (gchar *directory, gboolean is_user)
+scan_wm_directory (const gchar *directory, gboolean is_user)
 {
         GList *tmp_list;
         GList *files;
@@ -209,35 +212,29 @@ scan_wm_directory (gchar *directory, gboolean is_user)
                 tmp_list = tmp_list->next;
         }
 
-        g_list_foreach (files, (GFunc) g_free, NULL);
-        g_list_free (files);
+        g_list_free_full (files, g_free);
 }
 
-void mate_wm_manager_init(void)
+void
+mate_wm_manager_init (void)
 {
-	char* tempdir;
+        gchar *user_config_dir;
 
-	if (done_scan)
-	{
-		return;
-	}
+        if (done_scan)
+        {
+                return;
+        }
+        done_scan = TRUE;
 
-	done_scan = TRUE;
+        /* look up WMs on system config folder */
+        scan_wm_directory (MATE_WM_PROPERTY_PATH, FALSE);
 
-	tempdir = g_build_filename(MATE_WM_PROPERTY_PATH, NULL);
-	scan_wm_directory(tempdir, FALSE);
-	g_free(tempdir);
+        /* look up WMs on user config folder */
+        user_config_dir = g_build_filename (g_get_user_config_dir (), "mate", "wm-properties", NULL);
+        scan_wm_directory (user_config_dir, TRUE);
+        g_free (user_config_dir);
 
-	#if GLIB_CHECK_VERSION(2, 6, 0)
-		tempdir = g_build_filename(g_get_user_config_dir(), "mate", "wm-properties", NULL);
-	#else // glib version < 2.6.0
-		tempdir = g_build_filename(g_get_home_dir(), ".config", "mate", "wm-properties", NULL);
-	#endif
-
-	scan_wm_directory(tempdir, TRUE);
-	g_free(tempdir);
-
-	available_wms = g_list_sort(available_wms, wm_compare);
+        available_wms = g_list_sort (available_wms, wm_compare);
 }
 
 static AvailableWindowManager*
