@@ -14,14 +14,14 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __DR_WRIGHT_H__
 #define __DR_WRIGHT_H__
 
-#define MATECONF_PATH "/desktop/mate/typing_break"
+#define TYPING_BREAK_SCHEMA "org.mate.typing-break"
 
 typedef struct _DrWright DrWright;
 
